from .core import *
from .extra import *

__author__ = "naryal2580"
__version__ = "4.6"

del bad, blink, blue, blue_l, bold, core, cyan, cyan_l, dim, extra, good, green, green_l, hidden, invert, italic, name, NoRedirects, normal, purple, purple_l, red, red_l, request, rst, strike, style, uline, webrowser_openNewTab, white, white_l, yellow, yellow_l